==> jc-1.4.0.tar.gz: javax/imageio/ImageIO__24ImageReaderIterator.h <==
// final class javax.imageio.ImageIO$ImageReaderIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6445904bc943082b javax_imageio_ImageIO__24ImageReaderIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ImageReaderIterator_H_
#define _JC_javax_imageio_ImageIO__24ImageReaderIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$refs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object	_jc_javax_imageio_ImageIO__24ImageReaderIterator$object;

typedef const struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ImageReaderIterator$method$_init$883e05981aacbe90(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ImageReaderIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_imageio_ImageIO__24ImageReaderIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *);
extern void _jc_javax_imageio_ImageIO__24ImageReaderIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ImageReaderIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageReaderIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageReaderIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *);
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods	javax_imageio_ImageIO__24ImageReaderIterator;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs {
	struct _jc_object	*it;
	struct _jc_java_lang_Object$object	*readerExtension;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$refs {
    _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs	javax_imageio_ImageIO__24ImageReaderIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs	javax_imageio_ImageIO__24ImageReaderIterator;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object {
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype _jc_javax_imageio_ImageIO__24ImageReaderIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ImageReaderIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ImageReaderIterator$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ImageReaderIterator_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/ImageIO__24ImageReaderIterator.h <==
// final class javax.imageio.ImageIO$ImageReaderIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6445904bc943082b javax_imageio_ImageIO__24ImageReaderIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ImageReaderIterator_H_
#define _JC_javax_imageio_ImageIO__24ImageReaderIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$refs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs	_jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object	_jc_javax_imageio_ImageIO__24ImageReaderIterator$object;

typedef const struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ImageReaderIterator$method$_init$883e05981aacbe90(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ImageReaderIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_imageio_ImageIO__24ImageReaderIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_ImageIO__24ImageReaderIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ImageReaderIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageReaderIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageReaderIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vmethods	javax_imageio_ImageIO__24ImageReaderIterator;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs {
	struct _jc_object	*it;
	struct _jc_java_lang_Object$object	*readerExtension;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$refs {
    _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_refs	javax_imageio_ImageIO__24ImageReaderIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ImageReaderIterator$sub_nonrefs	javax_imageio_ImageIO__24ImageReaderIterator;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ImageReaderIterator$object {
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ImageReaderIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ImageReaderIterator$vtype _jc_javax_imageio_ImageIO__24ImageReaderIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ImageReaderIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ImageReaderIterator$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ImageReaderIterator_H_ */
